@@ -32,7 +32,8 @@ sub import {
   my @list = @_;
   unshift @list, '-Default' unless grep { $_ && $_ eq '-Default' } @list;
 
-  @list = map { split ';', $_ } @list;
+  # trim
+  @list = grep {$_} map { my $s = $_; $s =~ s/^\s+|\s+$//g; $s } map { split ';', $_ } @list;
   foreach my $key (@list) {
     my ($class, @args) = _parse($target, $key);
     load($class);
@@ -47,7 +48,7 @@ sub import {
 }
 
 
-our $VERSION = '0.0188';    # VERSION
+our $VERSION = '0.0189';    # VERSION
 
 1;
 
@@ -65,7 +66,7 @@ Evo - Evo - the next generation component-oriented development framework
 
 =head1 VERSION
 
-version 0.0188
+version 0.0189
 
 =head1 DESCRIPTION
 
@@ -102,6 +103,12 @@ L<Evo::Ee> - a component role that gives your component "EventEmitter" abilities
   # enables strict, warnings, utf8, :5.22, signatured, postderef
   use Evo;
 
+=head1 Vim UltiSnips
+
+=for HTML <p><img src="https://raw.github.com/alexbyk/perl-evo/master/demo.gif" alt="Perl Evo gif" /></p>
+
+Vim ultisnips with C<Evo> support can be found here: L<https://github.com/alexbyk/vim-ultisnips-perl>
+
 =head1 IMPORTING
 
 Load Module and call it's C<import> method, emulating C<caller>. 
