@@ -8,12 +8,12 @@ sub loop_start : Export        { DEFAULT->realm_lord->start(@_) }
 sub loop_timer : Export        { DEFAULT->realm_lord->timer(@_); }
 sub loop_timer_remove : Export { DEFAULT->realm_lord->timer_remove(@_); }
 
-sub loop_handle_in : Export         { DEFAULT->realm_lord->handle_in(@_) }
-sub loop_handle_out : Export        { DEFAULT->realm_lord->handle_out(@_) }
-sub loop_handle_error : Export      { DEFAULT->realm_lord->handle_error(@_) }
-sub loop_handle_remove_in : Export  { DEFAULT->realm_lord->handle_remove_in(@_); }
-sub loop_handle_remove_out : Export { DEFAULT->realm_lord->handle_remove_out(@_); }
-sub loop_handle_remove_all : Export { DEFAULT->realm_lord->handle_remove_all(@_); }
+sub loop_io_in : Export         { DEFAULT->realm_lord->io_in(@_) }
+sub loop_io_out : Export        { DEFAULT->realm_lord->io_out(@_) }
+sub loop_io_error : Export      { DEFAULT->realm_lord->io_error(@_) }
+sub loop_io_remove_in : Export  { DEFAULT->realm_lord->io_remove_in(@_); }
+sub loop_io_remove_out : Export { DEFAULT->realm_lord->io_remove_out(@_); }
+sub loop_io_remove_all : Export { DEFAULT->realm_lord->io_remove_all(@_); }
 
 sub loop_zone : Export                    { DEFAULT->realm_lord->zone(@_) }
 sub loop_postpone : prototype(&) : Export { DEFAULT->realm_lord->postpone(@_) }
@@ -32,7 +32,7 @@ Evo::Loop
 
 =head1 VERSION
 
-version 0.0188
+version 0.0189
 
 =head1 AUTHOR
 
